Class: Xoodyak
- Inherits:
-
Object
show all
- Defined in:
- lib/xoodyak.rb,
lib/xoodyak/version.rb,
sig/xoodyak.rbs
Overview
Define the Digest class in the Xoodyak namespace inheriting from Digest::Base,
so the C extension can successfully find it and attach the digest metadata.
Defined Under Namespace
Modules: Error
Classes: ArgumentError, Digest, KeyedModeError, VerificationError
Constant Summary
collapse
- VERSION =
"0.1.1"
Instance Method Summary
collapse
Constructor Details
Returns a new instance of Xoodyak.
22
|
# File 'sig/xoodyak.rbs', line 22
def initialize: (?String? key, ?nonce: String?, ?key_id: String?, ?counter: String?) -> void
|
Instance Method Details
#absorb ⇒ void
This method returns an undefined value.
24
|
# File 'sig/xoodyak.rbs', line 24
def absorb: (String bin) -> void
|
#aead_decrypt ⇒ String
30
|
# File 'sig/xoodyak.rbs', line 30
def aead_decrypt: (String bin) -> String
|
#aead_decrypt_detached ⇒ String
32
|
# File 'sig/xoodyak.rbs', line 32
def aead_decrypt_detached: (String bin, String tag) -> String
|
#aead_encrypt ⇒ String
29
|
# File 'sig/xoodyak.rbs', line 29
def aead_encrypt: (String bin) -> String
|
#aead_encrypt_detached ⇒ [String, String]
31
|
# File 'sig/xoodyak.rbs', line 31
def aead_encrypt_detached: (String bin) -> [String, String]
|
#decrypt ⇒ String
28
|
# File 'sig/xoodyak.rbs', line 28
def decrypt: (String bin) -> String
|
#encrypt ⇒ String
27
|
# File 'sig/xoodyak.rbs', line 27
def encrypt: (String bin) -> String
|
#initialize_copy ⇒ void
This method returns an undefined value.
23
|
# File 'sig/xoodyak.rbs', line 23
def initialize_copy: (Xoodyak other) -> void
|
#ratchet ⇒ void
This method returns an undefined value.
33
|
# File 'sig/xoodyak.rbs', line 33
def ratchet: () -> void
|
#squeeze ⇒ String
25
|
# File 'sig/xoodyak.rbs', line 25
def squeeze: (Integer len) -> String
|
#squeeze_key ⇒ String
26
|
# File 'sig/xoodyak.rbs', line 26
def squeeze_key: (Integer len) -> String
|