Class: Xoodyak

Inherits:
Object
  • Object
show all
Defined in:
lib/xoodyak.rb,
lib/xoodyak/version.rb

Overview

Define the Digest class in the Xoodyak namespace inheriting from Digest::Base, so the C extension can successfully find it and attach the digest metadata.

Defined Under Namespace

Classes: Digest

Constant Summary collapse

VERSION =
"0.1.0"